@@ -922,111 +922,101 @@ def test7_2(answer):
         )
 
 
-# # Project 7 Problem 1
-# def test7_1(answer):
-#     test = [
-#         ("tconst", "directors", "writers"),
-#         ("tt0000001", "nm0005690", "\\N"),
-#         ("tt0000002", "nm0721526", "\\N"),
-#         ("tt0000003", "nm0721526", "\\N"),
-#         ("tt0000004", "nm0721526", "\\N"),
-#         ("tt0000005", "nm0005690", "\\N"),
-#         ("tt0000006", "nm0005690", "\\N"),
-#         ("tt0000007", "nm0005690,nm0374658", "\\N"),
-#         ("tt0000008", "nm0005690", "\\N"),
-#         ("tt0000009", "nm0085156", "nm0085156"),
-#     ]
-#     if answer == test:
-#         print("Succotash")
-#     else:
-#         print(
-#             "Your result for 'SELECT * FROM movies_crew ORDER BY tconst LIMIT 10' does not match the expected result."
-#         )
+# # Project 8 Problem 1
+def test8_1(answer):
+    if round(answer,2) == round(3.823529411764706,2):
+        print("Succotash")
+    else:
+        print("Your answer is incorrect")
 
+def test8_2(answer):
+    if answer == 3.0:
+        print("Sassafras")
+    else:
+        print("Your answer is incorrect")
 
-# def test7_2(answer):
-#     test = [
-#         ("tt0102291", "nm0881355", "\\N"),
-#         ("tt0102290", "nm0310561,nm0628430", "nm0310561,nm0628430,nm0006219"),
-#         ("tt0102289", "nm0926301", "nm0926301"),
-#         ("tt0102288", "nm0575389", "nm0701031,nm0905498"),
-#         ("tt0102287", "nm0198699", "nm0198699,nm0959003"),
-#         ("tt0102286", "nm0950759", "nm2060068,nm0504980"),
-#         ("tt0102285", "nm0450661", "nm0863503,nm0450661"),
-#         ("tt0102284", "nm0394776", "nm0394776"),
-#         ("tt0102283", "nm0612730", "nm0730848"),
-#         ("tt0102282", "nm0059725", "nm0059725"),
-#     ]
-#     if answer == test:
-#         print("Sassafras")
-#     else:
-#         print(
-#             "Your result for 'SELECT * FROM movies_crew ORDER BY tconst DESC LIMIT 10' does not match the expected result."
-#         )
+def test8_3(answer):
+    if answer == 2:
+        print("Marmalade")
+    else:
+        print("Your answer is incorrect")
 
+def test8_4(answer):
+    if answer == 99:
+        print("Periwinkle")
+    else:
+        print("Your answer is incorrect")
 
-# # Project 7 Problem 2
-# def test7_3(answer):
-#     test = [
-#         ("tconst", "averageRating", "numVotes"),
-#         ("tt0000001", 5.7, 1993),
-#         ("tt0000002", 5.8, 268),
-#         ("tt0000003", 6.5, 1879),
-#         ("tt0000004", 5.5, 177),
-#         ("tt0000005", 6.2, 2662),
-#         ("tt0000006", 5.0, 182),
-#         ("tt0000007", 5.4, 834),
-#         ("tt0000008", 5.4, 2136),
-#         ("tt0000009", 5.3, 206),
-#     ]
-#     if answer == test:
-#         print("Marmalade")
-#     else:
-#         print(
-#             "Your result for 'SELECT * FROM movies_ratings ORDER BY tconst LIMIT 10' does not match the expected result."
-#         )
+def test8_5(answer):
+    if answer == 80.0:
+        print("Vantablack")
+    else:
+        print("Your answer is incorrect")
 
+def test8_6(answer):
+    if answer == 50.0:
+        print("Heliotrope")
+    else:
+        print("Your answer is incorrect")
 
-# def test7_4(answer):
-#     test = [
-#         ("tt0139287", 6.8, 12),
-#         ("tt0139286", 6.1, 13),
-#         ("tt0139283", 6.8, 102),
-#         ("tt0139276", 7.1, 105),
-#         ("tt0139275", 5.7, 136),
-#         ("tt0139274", 5.2, 140),
-#         ("tt0139272", 5.5, 140),
-#         ("tt0139269", 5.7, 26),
-#         ("tt0139267", 5.1, 22),
-#         ("tt0139266", 5.3, 113),
-#     ]
-#     if answer == test:
-#         print("Periwinkle")
-#     else:
-#         print(
-#             "Your result for 'SELECT * FROM movies_ratings ORDER BY tconst DESC LIMIT 10' does not match the expected result."
-#         )
+# Project 8 Problem 2
+def test8_7(answer):
+    if answer == "Skewed Left":
+        print("Aztech Anarchists")
+    else:
+        print("Your answer is incorrect")
 
+def test8_8(answer):
+    if answer == "Uniform":
+        print("Mesopotamian Malarkey")
+    else:
+        print("Your answer is incorrect")
 
-# # Project 7 Problem 3
-# def test7_5(answer):
-#     test = [
-#         ("The Simpsons", 8.7, 424381),
-#         ("Star Wars: Episode IV - A New Hope", 8.6, 1414060),
-#         ("Mr. Bean", 8.6, 128266),
-#         ("Apocalypse Now", 8.4, 692100),
-#         ("Amadeus", 8.4, 416996),
-#         ("Network", 8.1, 165776),
-#         ("Dog Day Afternoon", 8.0, 267726),
-#         ("The Conversation", 7.8, 117551),
-#         ("Serpico", 7.7, 130667),
-#         ("The Godfather Part III", 7.6, 413886),
-#     ]
-#     if answer == test:
-#         print("Vantablack")
-#     else:
-#         print(
-#             "Your query does not return the expected results. The top 10 expected films (not in order) are: The Godfather Part III, The Conversation, Network, Apocalypse Now, Star Wars: Episode IV - A New Hope, Sercipo, Dog Day Afternoon, Amadeus, Mr. Bean, The Simpsons"
-#         )
+def test8_9(answer):
+    if answer == "Skewed Left":
+        print("Mayan Maniacs")
+    else:
+        print("Your answer is incorrect")
 
+def test8_10(answer):
+    if answer == "Skewed Right":
+        print("Incan Insurrectionists")
+    else:
+        print("Your answer is incorrect")
 
+def test8_11(answer):
+    if round(answer,2) == round(2.6568446566202857,2):
+        print("Babylonian Berators")
+    else:
+        print("Your answer is incorrect")
+
+def test8_12(answer):
+    if round(answer,2) == round(28.418269462014862,2):
+        print("Olmec Oafs")
+    else:
+        print("Your answer is incorrect")
+
+# Project 8 Problem 3
+def test8_13(answer):
+    if round(answer,2) == round(0.04115008490213371,2):
+        print("Cattywampus")
+    else:
+        print("Your answer is incorrect")
+
+def test8_14(answer):
+    if round(answer,2) == round(-0.716706638107379,2):
+        print("Taradiddle")
+    else:
+        print("Your answer is incorrect")
+
+def test8_15(answer):
+    if round(answer,2) == round(0.899303319511589,2):
+        print("Widdershins")
+    else:
+        print("Your answer is incorrect")
+
+def test8_16(answer):
+    if round(answer,2) == round(1.622486023897098,2):
+        print("Collywobbles")
+    else:
+        print("Your answer is incorrect")
